@@ -56,7 +56,7 @@ class MultiqcModule(BaseMultiqcModule):
             try:
                 fqc_zip = zipfile.ZipFile(os.path.join(f['root'], f['fn']))
             except Exception as e:
-                log.warn("Couldn't read '{}' - Bad zip file".format(f['fn']))
+                log.warning("Couldn't read '{}' - Bad zip file".format(f['fn']))
                 log.debug("Bad zip file error:\n{}".format(e))
                 continue
             # FastQC zip files should have just one directory inside, containing report
@@ -199,15 +199,26 @@ class MultiqcModule(BaseMultiqcModule):
         data = dict()
         for s_name in self.fastqc_data:
             bs = self.fastqc_data[s_name]['basic_statistics']
-            data[s_name] = {
-                'percent_gc': bs['%GC'],
-                'avg_sequence_length': bs['avg_sequence_length'],
-                'total_sequences': bs['Total Sequences'],
-            }
             try:
+                # FastQC reports with 0 reads will trigger a KeyError here
+                data[s_name] = {
+                    'percent_gc': bs['%GC'],
+                    'avg_sequence_length': bs['avg_sequence_length'],
+                    'total_sequences': bs['Total Sequences'],
+                }
+            except KeyError:
+                log.warning("Sample had zero reads: '{}'".format(s_name))
+                data[s_name] = {
+                    'percent_gc': 0,
+                    'avg_sequence_length': 0,
+                    'total_sequences': 0,
+                }
+            try:
+                # Older versions of FastQC don't have this
                 data[s_name]['percent_duplicates'] = 100 - bs['total_deduplicated_percentage']
             except KeyError:
-                pass # Older versions of FastQC don't have this
+                pass
+
             # Add count of fail statuses
             num_statuses = 0
             num_fails = 0
@@ -215,11 +226,19 @@ class MultiqcModule(BaseMultiqcModule):
                 num_statuses += 1
                 if s == 'fail':
                     num_fails += 1
-            data[s_name]['percent_fails'] = (float(num_fails)/float(num_statuses))*100.0
+            try:
+                data[s_name]['percent_fails'] = (float(num_fails)/float(num_statuses))*100.0
+            except KeyError:
+                # If we had no reads then we have no sample in data
+                pass
 
         # Are sequence lengths interesting?
         seq_lengths = [x['avg_sequence_length'] for x in data.values()]
-        hide_seq_length = False if max(seq_lengths) - min(seq_lengths) > 10 else True
+        try:
+            hide_seq_length = False if max(seq_lengths) - min(seq_lengths) > 10 else True
+        except ValueError:
+            # Zero reads
+            hide_seq_length = True
 
         headers = OrderedDict()
         headers['percent_duplicates'] = {
@@ -519,7 +538,10 @@ class MultiqcModule(BaseMultiqcModule):
                 data_norm[s_name] = dict()
                 total = sum( [ c for c in data[s_name].values() ] )
                 for gc, count in data[s_name].items():
-                    data_norm[s_name][gc] = (count / total) * 100
+                    try:
+                        data_norm[s_name][gc] = (count / total) * 100
+                    except ZeroDivisionError:
+                        data_norm[s_name][gc] = 0
         if len(data) == 0:
             log.debug('per_sequence_gc_content not found in FastQC reports')
             return None
@@ -528,6 +550,7 @@ class MultiqcModule(BaseMultiqcModule):
             'id': 'fastqc_per_sequence_gc_content_plot',
             'title': 'FastQC: Per Sequence GC Content',
             'xlab': '% GC',
+            'ylab': 'Percentage',
             'ymin': 0,
             'xmax': 100,
             'xmin': 0,
@@ -546,7 +569,7 @@ class MultiqcModule(BaseMultiqcModule):
         theoretical_gc_name = None
         for f in self.find_log_files('fastqc/theoretical_gc'):
             if theoretical_gc_raw is not None:
-                log.warn("Multiple FastQC Theoretical GC Content files found, now using {}".format(f['fn']))
+                log.warning("Multiple FastQC Theoretical GC Content files found, now using {}".format(f['fn']))
             theoretical_gc_raw = f['f']
             theoretical_gc_name = f['fn']
         if theoretical_gc_raw is None:
@@ -561,7 +584,7 @@ class MultiqcModule(BaseMultiqcModule):
                     with io.open (tgc_path, "r", encoding='utf-8') as f:
                         theoretical_gc_raw = f.read()
                 except IOError:
-                    log.warn("Couldn't open FastQC Theoretical GC Content file {}".format(tgc_path))
+                    log.warning("Couldn't open FastQC Theoretical GC Content file {}".format(tgc_path))
                     theoretical_gc_raw = None
         if theoretical_gc_raw is not None:
             theoretical_gc = list()
@@ -753,8 +776,10 @@ class MultiqcModule(BaseMultiqcModule):
             'ymax': 100 if max_dupval <= 100.0 else None,
             'ymin': 0,
             'yMinTickInterval': 0.1,
+            'yLabelFormat': '{value:.0f}%',
             'colors': self.get_status_cols('sequence_duplication_levels'),
-            'tt_label': '<b>{point.x}</b>: {point.y:.1f}%',
+            'tt_decimals': 2,
+            'tt_suffix': '%'
         }
 
         self.add_section (
@@ -981,34 +1006,35 @@ class MultiqcModule(BaseMultiqcModule):
             ],
             'decimalPlaces': 1,
             'legend': False,
-            'datalabels': False
+            'datalabels': False,
+            'xcats_samples': False
         }
 
         self.add_section (
             name = 'Status Checks',
             anchor = 'fastqc_status_checks',
             description = '''
-            Status for each FastQC section showing whether results seem entirely normal (green),
-            slightly abnormal (orange) or very unusual (red).
+                Status for each FastQC section showing whether results seem entirely normal (green),
+                slightly abnormal (orange) or very unusual (red).
             ''',
             helptext = '''
-            FastQC assigns a status for each section of the report.
-            These give a quick evaluation of whether the results of the analysis seem
-            entirely normal (green), slightly abnormal (orange) or very unusual (red).
+                FastQC assigns a status for each section of the report.
+                These give a quick evaluation of whether the results of the analysis seem
+                entirely normal (green), slightly abnormal (orange) or very unusual (red).
 
-            It is important to stress that although the analysis results appear to give a pass/fail result,
-            these evaluations must be taken in the context of what you expect from your library.
-            A 'normal' sample as far as FastQC is concerned is random and diverse.
-            Some experiments may be expected to produce libraries which are biased in particular ways.
-            You should treat the summary evaluations therefore as pointers to where you should concentrate
-            your attention and understand why your library may not look random and diverse.
+                It is important to stress that although the analysis results appear to give a pass/fail result,
+                these evaluations must be taken in the context of what you expect from your library.
+                A 'normal' sample as far as FastQC is concerned is random and diverse.
+                Some experiments may be expected to produce libraries which are biased in particular ways.
+                You should treat the summary evaluations therefore as pointers to where you should concentrate
+                your attention and understand why your library may not look random and diverse.
 
-            Specific guidance on how to interpret the output of each module can be found in the relevant
-            report section, or in the [FastQC help](https://www.bioinformatics.babraham.ac.uk/projects/fastqc/Help/3%20Analysis%20Modules/).
+                Specific guidance on how to interpret the output of each module can be found in the relevant
+                report section, or in the [FastQC help](https://www.bioinformatics.babraham.ac.uk/projects/fastqc/Help/3%20Analysis%20Modules/).
 
-            In this heatmap, we summarise all of these into a single heatmap for a quick overview.
-            Note that not all FastQC sections have plots in MultiQC reports, but all status checks
-            are shown in this heatmap.
+                In this heatmap, we summarise all of these into a single heatmap for a quick overview.
+                Note that not all FastQC sections have plots in MultiQC reports, but all status checks
+                are shown in this heatmap.
             ''',
             plot = heatmap.plot(data, list(status_cats.values()), s_names, pconfig)
         )
