@@ -1,9 +1,12 @@
 """ MultiQC module to parse output from fgbio """
 import logging
+from collections import OrderedDict
 
 from multiqc.modules.base_module import BaseMultiqcModule
 
 from .groupreadsbyumi import GroupReadsByUmiMixin
+from . import ErrorRateByReadPosition
+
 
 # Initialise the logger
 log = logging.getLogger(__name__)
@@ -23,11 +26,24 @@ class MultiqcModule(BaseMultiqcModule, GroupReadsByUmiMixin):
             info=("  is a command line toolkit for working with genomic and "
                   "particularly next generation sequencing data.."))
 
+        # Set up class objects to hold parsed data
+        self.general_stats_headers = OrderedDict()
+        self.general_stats_data = dict()
+
+        # GroupReadsByUmi
         n = dict()
         n['groupreadsbyumi'] = self.parse_groupreadsbyumi()
         if n['groupreadsbyumi'] > 0:
             log.info("Found {} groupreadsbyumi reports".format(n['groupreadsbyumi']))
 
+        # ErrorRateByReadPoosition
+        n['errorratebyreadposition'] = ErrorRateByReadPosition.parse_reports(self)
+        if n['errorratebyreadposition'] > 0:
+            log.info("Found {} errorratebyreadposition reports".format(n['errorratebyreadposition']))
+
         # Exit if we didn't find anything
         if sum(n.values()) == 0:
             raise UserWarning
+
+        # Add to the General Stats table (has to be called once per MultiQC module)
+        self.general_stats_addcols(self.general_stats_data, self.general_stats_headers)
