@@ -49,16 +49,16 @@ class MultiqcModule(BaseMultiqcModule, FindPeaksReportMixin, TagDirReportMixin):
 
         }
         # Call submodule functions
-        
+
 
         n['findpeaks'] = self.parse_homer_findpeaks()
         if n['findpeaks'] > 0:
             log.info("Found {} findPeaks reports".format(n['findpeaks']))
 
-    
-        n['Homer_tagDir'] = self.homer_tagdirectory()
-        if n['Homer_tagDir'] > 0:
-            log.info("Found {} reports".format(n['Homer_tagDir']))
+
+        n['tagDir'] = self.homer_tagdirectory()
+        if n['tagDir'] > 0:
+            log.info("Found {} tagDir reports".format(n['tagDir']))
 
         # Exit if we didn't find anything
         if sum(n.values()) == 0:
