@@ -22,7 +22,8 @@ def parse_reports(self):
     for f in self.find_log_files('qualimap/bamqc/genome_results'):
         parse_genome_results(self, f)
     self.qualimap_bamqc_genome_results = self.ignore_samples(self.qualimap_bamqc_genome_results)
-    self.write_data_file(self.qualimap_bamqc_genome_results, 'multiqc_qualimap_bamqc_genome_results')
+    if len(self.qualimap_bamqc_genome_results) > 0:
+        self.write_data_file(self.qualimap_bamqc_genome_results, 'multiqc_qualimap_bamqc_genome_results')
 
     # Coverage - coverage_histogram.txt
     self.qualimap_bamqc_coverage_hist = dict()
@@ -41,6 +42,7 @@ def parse_reports(self):
     self.qualimap_bamqc_gc_by_species = dict()  # {'HUMAN': data_dict, 'MOUSE': data_dict}
     for f in self.find_log_files('qualimap/bamqc/gc_dist', filehandles=True):
         parse_gc_dist(self, f)
+    self.qualimap_bamqc_gc_content_dist = self.ignore_samples(self.qualimap_bamqc_gc_content_dist)
     self.qualimap_bamqc_gc_by_species = self.ignore_samples(self.qualimap_bamqc_gc_by_species)
 
     num_parsed = max(
@@ -86,6 +88,7 @@ def parse_genome_results(self, f):
         'median_insert_size': r"median insert size = ([\d,\.]+)",
         'mean_mapping_quality': r"mean mapping quality = ([\d,\.]+)",
         'general_error_rate': r"general error rate = ([\d,\.]+)",
+        'mean_coverage': r"mean coverageData = ([\d,\.]+)"
     }
     d = dict()
     for k, r in regexes.items():
@@ -110,6 +113,7 @@ def parse_genome_results(self, f):
         d['percentage_aligned'] = (d['mapped_reads'] / d['total_reads'])*100
         self.general_stats_data[s_name]['percentage_aligned'] = d['percentage_aligned']
         self.general_stats_data[s_name]['general_error_rate'] = d['general_error_rate']*100
+        self.general_stats_data[s_name]['mean_coverage'] = d['mean_coverage']
     except KeyError:
         pass
 
@@ -139,7 +143,7 @@ def parse_coverage(self, f):
         log.debug("Couldn't parse contents of coverage histogram file {}".format(f['fn']))
         return None
 
-    # Find median and mean without importing anything to do it for us
+    # Find median without importing anything to do it for us
     num_counts = sum(d.values())
     cum_counts = 0
     total_cov = 0
@@ -150,13 +154,7 @@ def parse_coverage(self, f):
         if cum_counts >= num_counts/2:
             median_coverage = thiscov
             break
-    try:
-        self.general_stats_data[s_name]['mean_coverage'] = total_cov / num_counts
-    except ZeroDivisionError:
-        self.general_stats_data[s_name]['mean_coverage'] = 0
-
     self.general_stats_data[s_name]['median_coverage'] = median_coverage
-
     # Save results
     if s_name in self.qualimap_bamqc_coverage_hist:
         log.debug("Duplicate coverage histogram sample name found! Overwriting: {}".format(s_name))
