@@ -5,10 +5,12 @@
 from __future__ import print_function, division
 from collections import OrderedDict
 import base64
+import inspect
 import io
 import logging
 import os
 import random
+import re
 import sys
 
 from multiqc.utils import config, report, util_functions
@@ -58,6 +60,28 @@ def plot (data, pconfig=None):
     if type(data) is not list:
         data = [data]
 
+    # Validate config if linting
+    if config.lint:
+        # Get module name
+        modname = ''
+        callstack = inspect.stack()
+        for n in callstack:
+            if 'multiqc/modules/' in n[1] and 'base_module.py' not in n[1]:
+                callpath = n[1].split('multiqc/modules/',1)[-1]
+                modname = '>{}< '.format(callpath)
+                break
+        # Look for essential missing pconfig keys
+        for k in ['id', 'title', 'ylab']:
+            if k not in pconfig:
+                errmsg = "LINT: {}Linegraph pconfig was missing key '{}'".format(modname, k)
+                logger.error(errmsg)
+                report.lint_errors.append(errmsg)
+        # Check plot title format
+        if not re.match( r'^[^:]*\S: \S[^:]*$', pconfig.get('title', '')):
+            errmsg = "LINT: {} Linegraph title did not match format 'Module: Plot Name' (found '{}')".format(modname, pconfig.get('title', ''))
+            logger.error(errmsg)
+            report.lint_errors.append(errmsg)
+
     # Smooth dataset if requested in config
     if pconfig.get('smooth_points', None) is not None:
         sumcounts = pconfig.get('smooth_points_sumcounts', True)
@@ -182,6 +206,23 @@ def highcharts_linegraph (plotdata, pconfig=None):
     # Build the HTML for the page
     html = '<div class="mqc_hcplot_plotgroup">'
 
+    # Log Switch
+    if pconfig.get('logswitch') is True:
+        c_active = 'active'
+        l_active = ''
+        if pconfig.get('logswitch_active') is True:
+            c_active = ''
+            l_active = 'active'
+        c_label = pconfig.get('cpswitch_counts_label', 'Counts')
+        l_label = pconfig.get('logswitch_label', 'Log10')
+        html += '<div class="btn-group hc_switch_group"> \n'
+        html += '<button class="btn btn-default btn-sm {c_a}" data-action="set_numbers" data-target="{id}" data-ylab="{c_l}">{c_l}</button> \n'.format(id=pconfig['id'], c_a=c_active, c_l=c_label)
+        if pconfig.get('logswitch') is True:
+            html += '<button class="btn btn-default btn-sm {l_a}" data-action="set_log" data-target="{id}" data-ylab="{l_l}">{l_l}</button> \n'.format(id=pconfig['id'], l_a=l_active, l_l=l_label)
+        html += '</div> '
+        if len(plotdata) > 1:
+            html += ' &nbsp; &nbsp; '
+
     # Buttons to cycle through different datasets
     if len(plotdata) > 1:
         html += '<div class="btn-group hc_switch_group">\n'
